# CHANGELOG

## Release 0.9.3-alpha -- 2022-03-21

* Change default output directory to ./.
* Support multiple input files.
* Add --sanitize option.

## Release 0.9.2-alpha -- 2022-03-20

* Mypy and flakeheaven code cleanups.

## Release 0.9.1-alpha -- 2022-03-19

* Initial alpha release.
